###################################################################################
:mod:`.accessibility <highcharts_core.global_options.language.accessibility>`
###################################################################################

.. contents:: Module Contents
  :local:
  :depth: 3
  :backlinks: entry

.. toctree::
  :titlesonly:

  announce_new_data
  axis
  chart_types
  exporting
  legend
  range_selector
  screen_reader_section
  series
  sonification
  table
  zoom

--------------

.. module:: highcharts_core.global_options.language.accessibility

****************************************************************************************************************************************
class: :class:`AccessibilityLanguageOptions <highcharts_core.global_options.language.accessibility.AccessibilityLanguageOptions>`
****************************************************************************************************************************************

.. autoclass:: AccessibilityLanguageOptions
  :members:
  :inherited-members:

  .. collapse:: Class Inheritance

    .. inheritance-diagram:: AccessibilityLanguageOptions
      :top-classes: highcharts_core.metaclasses.HighchartsMeta
      :parts: -1

  |

--------------------

******************
Sub-components
******************

.. list-table::
  :widths: 60 40
  :header-rows: 2

  * - Module
    - Classes / Functions
  * - :mod:`.global_options.language.accessibility <highcharts_core.global_options.language.accessibility>`
    - :class:`AccessibilityLanguageOptions <highcharts_core.global_options.language.accessibility.AccessibilityLanguageOptions>`
  * - :mod:`.global_options.language.accessibility.announce_new_data <highcharts_core.global_options.language.accessibility.announce_new_data>`
    - :class:`AnnounceNewDataLanguageOptions <highcharts_core.global_options.language.accessibility.announce_new_data.AnnounceNewDataLanguageOptions>`
  * - :mod:`.global_options.language.accessibility.axis <highcharts_core.global_options.language.accessibility.axis>`
    - :class:`AxisLanguageOptions <highcharts_core.global_options.language.accessibility.axis.AxisLanguageOptions>`
  * - :mod:`global_options.language.accessibility.chart_types <highcharts_core.global_options.language.accessibility.chart_types>`
    - :class:`ChartTypesLanguageOptions <highcharts_core.global_options.language.accessibility.chart_types.ChartTypesLanguageOptions>`
  * - :mod:`global_options.language.accessibility.exporting <highcharts_core.global_options.language.accessibility.exporting>`
    - :class:`ExportingLanguageOptions <highcharts_core.global_options.language.accessibility.exporting.ExportingLanguageOptions>`
  * - :mod:`global_options.language.accessibility.legend <highcharts_core.global_options.language.accessibility.legend>`
    - :class:`LegendLanguageOptions <highcharts_core.global_options.language.accessibility.legend.LegendLanguageOptions>`
  * - :mod:`global_options.language.accessibility.range_selector <highcharts_core.global_options.language.accessibility.range_selector>`
    - :class:`RangeSelectorLanguageOptions <highcharts_core.global_options.language.accessibility.range_selector.RangeSelectorLanguageOptions>`
  * - :mod:`global_options.language.accessibility.screen_reader_section <highcharts_core.global_options.language.accessibility.screen_reader_section>`
    - :class:`ScreenReaderSectionLanguageOptions <highcharts_core.global_options.language.accessibility.screen_reader_section.ScreenReaderSectionLanguageOptions>`
      :class:`ScreenReaderSectionAnnotationLanguage <highcharts_core.global_options.language.accessibility.screen_reader_section.ScreenReaderSectionAnnotationLanguage>`
  * - :mod:`global_options.language.accessibility.series <highcharts_core.global_options.language.accessibility.series>`
    - :class:`SeriesLanguageOptions <highcharts_core.global_options.language.accessibility.series.SeriesLanguageOptions>`
      :class:`SeriesSummaryLanguageOptions <highcharts_core.global_options.language.accessibility.series.SeriesSummaryLanguageOptions>`
      :class:`SeriesTypeDescriptions <highcharts_core.global_options.language.accessibility.series.SeriesTypeDescriptions>`
  * - :mod:`global_options.language.accessibility.sonification <highcharts_core.global_options.language.accessibility.sonification>`
    - :class:`SonificationLanguageOptions <highcharts_core.global_options.language.accessibility.sonification.SonificationLanguageOptions>`
  * - :mod:`global_options.language.accessibility.table <highcharts_core.global_options.language.accessibility.table>`
    - :class:`TableLanguageOptions <highcharts_core.global_options.language.accessibility.table.TableLanguageOptions>`
  * - :mod:`global_options.language.accessibility.zoom <highcharts_core.global_options.language.accessibility.zoom>`
    - :class:`ZoomLanguageOptions <highcharts_core.global_options.language.accessibility.zoom.ZoomLanguageOptions>`
